/*
=NODE  KeysDistr   Keys for Distribution String
=UP StringDistr [10]

=DESCRIPTION

List of standard distributions @pxref{Stddist,,Standard distributions}

@itemize @minus
@item @code{[distr =] beta(@dots{})} @ @ @ @  @result{} @pxref{beta}
@item @code{[distr =] binomial(@dots{})} @ @ @ @  @result{} @pxref{binomial}
@item @code{[distr =] cauchy(@dots{})} @ @ @ @  @result{} @pxref{cauchy}
@item @code{[distr =] chi(@dots{})} @ @ @ @  @result{} @pxref{chi}
@item @code{[distr =] chisquare(@dots{})} @ @ @ @  @result{} @pxref{chisquare}
@item @code{[distr =] exponential(@dots{})} @ @ @ @  @result{} @pxref{exponential}
@item @code{[distr =] extremeI(@dots{})} @ @ @ @  @result{} @pxref{extremeI}
@item @code{[distr =] extremeII(@dots{})} @ @ @ @  @result{} @pxref{extremeII}
@item @code{[distr =] gamma(@dots{})} @ @ @ @  @result{} @pxref{gamma}
@item @code{[distr =] geometric(@dots{})} @ @ @ @  @result{} @pxref{geometric}
@item @code{[distr =] hypergeometric(@dots{})} @ @ @ @  @result{} @pxref{hypergeometric}
@item @code{[distr =] laplace(@dots{})} @ @ @ @  @result{} @pxref{laplace}
@item @code{[distr =] logarithmic(@dots{})} @ @ @ @  @result{} @pxref{logarithmic}
@item @code{[distr =] logistic(@dots{})} @ @ @ @  @result{} @pxref{logistic}
@item @code{[distr =] lomax(@dots{})} @ @ @ @  @result{} @pxref{lomax}
@item @code{[distr =] negativebinomial(@dots{})} @ @ @ @  @result{} @pxref{negativebinomial}
@item @code{[distr =] normal(@dots{})} @ @ @ @  @result{} @pxref{normal}
@item @code{[distr =] pareto(@dots{})} @ @ @ @  @result{} @pxref{pareto}
@item @code{[distr =] poisson(@dots{})} @ @ @ @  @result{} @pxref{poisson}
@item @code{[distr =] powerexponential(@dots{})} @ @ @ @  @result{} @pxref{powerexponential}
@item @code{[distr =] rayleigh(@dots{})} @ @ @ @  @result{} @pxref{rayleigh}
@item @code{[distr =] student(@dots{})} @ @ @ @  @result{} @pxref{student}
@item @code{[distr =] triangular(@dots{})} @ @ @ @  @result{} @pxref{triangular}
@item @code{[distr =] uniform(@dots{})} @ @ @ @  @result{} @pxref{uniform}
@item @code{[distr =] weibull(@dots{})} @ @ @ @  @result{} @pxref{weibull}
@end itemize

@sp 1
List of generic distributions @pxref{Distribution_objects,,Handling Distribution Objects}

@itemize @minus
@item @code{[distr =] cemp} @ @ @ @  @result{} @pxref{CEMP}
@item @code{[distr =] cont} @ @ @ @  @result{} @pxref{CONT}
@item @code{[distr =] discr} @ @ @ @  @result{} @pxref{DISCR}
@end itemize

@sp 1
@emph{Notice}:
Order statistics for continuous distributions (@pxref{CORDER}) are
supported by using the key @code{orderstatistics} for distributions
of type @code{CONT}.

@sp 1

List of keys that are available via the String API.
For description see the corresponding UNURAN set calls.

@itemize @bullet
@item All distribution types
@table @code
@item name = "@i{<string>}"
 @result{} @pxref{funct:unur_distr_set_name,,@command{unur_distr_set_name}}
@end table

@sp 1
@item @code{cemp} @ @i{(Distribution Type)}@ @ @ @ (@pxref{CEMP})
@table @code
@item data = (@i{<list>}) [, @i{<int>}]
 @result{} @pxref{funct:unur_distr_cemp_set_data,,@command{unur_distr_cemp_set_data}}
@end table

@sp 1
@item @code{cont} @ @i{(Distribution Type)}@ @ @ @ (@pxref{CONT})
@table @code
@item cdf = "@i{<string>}"
 @result{} @pxref{funct:unur_distr_cont_set_cdfstr,,@command{unur_distr_cont_set_cdfstr}}
@item domain = @i{<double>}, @i{<double>} | (@i{<list>})
 @result{} @pxref{funct:unur_distr_cont_set_domain,,@command{unur_distr_cont_set_domain}}
@item mode = @i{<double>}
 @result{} @pxref{funct:unur_distr_cont_set_mode,,@command{unur_distr_cont_set_mode}}
@item pdf = "@i{<string>}"
 @result{} @pxref{funct:unur_distr_cont_set_pdfstr,,@command{unur_distr_cont_set_pdfstr}}
@item pdfarea = @i{<double>}
 @result{} @pxref{funct:unur_distr_cont_set_pdfarea,,@command{unur_distr_cont_set_pdfarea}}
@item pdfparams = (@i{<list>}) [, @i{<int>}]
 @result{} @pxref{funct:unur_distr_cont_set_pdfparams,,@command{unur_distr_cont_set_pdfparams}}
@item orderstatistics = @i{<int>}, @i{<int>} | (@i{<list>})
    Make order statistics for given distribution. The first parameter
    gives the sample size, the second parameter its rank.
    It must be the last keyword for a distribution string.
    (see @pxref{funct:unur_distr_corder_new,,@command{unur_distr_corder_new}})
@end table

@sp 1
@item @code{discr} @ @i{(Distribution Type)}@ @ @ @ (@pxref{DISCR})
@table @code
@item cdf = "@i{<string>}"
 @result{} @pxref{funct:unur_distr_discr_set_cdfstr,,@command{unur_distr_discr_set_cdfstr}}
@item domain = @i{<int>}, @i{<int>} | (@i{<list>})
 @result{} @pxref{funct:unur_distr_discr_set_domain,,@command{unur_distr_discr_set_domain}}
@item mode [= @i{<int>}]
 @result{} @pxref{funct:unur_distr_discr_set_mode,,@command{unur_distr_discr_set_mode}}
@item pmf = "@i{<string>}"
 @result{} @pxref{funct:unur_distr_discr_set_pmfstr,,@command{unur_distr_discr_set_pmfstr}}
@item pmfparams = (@i{<list>}) [, @i{<int>}]
 @result{} @pxref{funct:unur_distr_discr_set_pmfparams,,@command{unur_distr_discr_set_pmfparams}}
@item pmfsum = @i{<double>}
 @result{} @pxref{funct:unur_distr_discr_set_pmfsum,,@command{unur_distr_discr_set_pmfsum}}
@item pv = (@i{<list>}) [, @i{<int>}]
 @result{} @pxref{funct:unur_distr_discr_set_pv,,@command{unur_distr_discr_set_pv}}
@end table

@sp 1
@end itemize


=EON
*/
/*
=NODE  KeysMethod   Keys for Method String
=UP StringMethod [10]

=DESCRIPTION

List of methods and keys that are available via the String API.
For description see the corresponding UNURAN set calls.

@itemize @bullet
@item @code{method = arou} @ @ @ @  @result{} @command{unur_arou_new}
(@pxref{AROU})
@table @code
@item center = @i{<double>}
 @result{} @pxref{funct:unur_arou_set_center,,@command{unur_arou_set_center}}
@item cpoints = @i{<int>} [, (@i{<list>})] | (@i{<list>})
 @result{} @pxref{funct:unur_arou_set_cpoints,,@command{unur_arou_set_cpoints}}
@item guidefactor = @i{<double>}
 @result{} @pxref{funct:unur_arou_set_guidefactor,,@command{unur_arou_set_guidefactor}}
@item max_segments [= @i{<int>}]
 @result{} @pxref{funct:unur_arou_set_max_segments,,@command{unur_arou_set_max_segments}}
@item max_sqhratio = @i{<double>}
 @result{} @pxref{funct:unur_arou_set_max_sqhratio,,@command{unur_arou_set_max_sqhratio}}
@item pedantic [= @i{<int>}]
 @result{} @pxref{funct:unur_arou_set_pedantic,,@command{unur_arou_set_pedantic}}
@item usecenter [= @i{<int>}]
 @result{} @pxref{funct:unur_arou_set_usecenter,,@command{unur_arou_set_usecenter}}
@item verify [= @i{<int>}]
 @result{} @pxref{funct:unur_arou_set_verify,,@command{unur_arou_set_verify}}
@end table

@sp 1
@item @code{method = auto} @ @ @ @  @result{} @command{unur_auto_new}
(@pxref{AUTO})
@table @code
@item logss [= @i{<int>}]
 @result{} @pxref{funct:unur_auto_set_logss,,@command{unur_auto_set_logss}}
@end table

@sp 1
@item @code{method = cstd} @ @ @ @  @result{} @command{unur_cstd_new}
(@pxref{CSTD})
@table @code
@item variant = @i{<unsigned>}
 @result{} @pxref{funct:unur_cstd_set_variant,,@command{unur_cstd_set_variant}}
@end table

@sp 1
@item @code{method = dari} @ @ @ @  @result{} @command{unur_dari_new}
(@pxref{DARI})
@table @code
@item cpfactor = @i{<double>}
 @result{} @pxref{funct:unur_dari_set_cpfactor,,@command{unur_dari_set_cpfactor}}
@item squeeze [= @i{<int>}]
 @result{} @pxref{funct:unur_dari_set_squeeze,,@command{unur_dari_set_squeeze}}
@item tablesize [= @i{<int>}]
 @result{} @pxref{funct:unur_dari_set_tablesize,,@command{unur_dari_set_tablesize}}
@item verify [= @i{<int>}]
 @result{} @pxref{funct:unur_dari_set_verify,,@command{unur_dari_set_verify}}
@end table

@sp 1
@item @code{method = dau} @ @ @ @  @result{} @command{unur_dau_new}
(@pxref{DAU})
@table @code
@item urnfactor = @i{<double>}
 @result{} @pxref{funct:unur_dau_set_urnfactor,,@command{unur_dau_set_urnfactor}}
@end table

@sp 1
@item @code{method = dgt} @ @ @ @  @result{} @command{unur_dgt_new}
(@pxref{DGT})
@table @code
@item guidefactor = @i{<double>}
 @result{} @pxref{funct:unur_dgt_set_guidefactor,,@command{unur_dgt_set_guidefactor}}
@item variant = @i{<unsigned>}
 @result{} @pxref{funct:unur_dgt_set_variant,,@command{unur_dgt_set_variant}}
@end table

@sp 1
@item @code{method = dsrou} @ @ @ @  @result{} @command{unur_dsrou_new}
(@pxref{DSROU})
@table @code
@item cdfatmode = @i{<double>}
 @result{} @pxref{funct:unur_dsrou_set_cdfatmode,,@command{unur_dsrou_set_cdfatmode}}
@item verify [= @i{<int>}]
 @result{} @pxref{funct:unur_dsrou_set_verify,,@command{unur_dsrou_set_verify}}
@end table

@sp 1
@item @code{method = dstd} @ @ @ @  @result{} @command{unur_dstd_new}
(@pxref{DSTD})
@table @code
@item variant = @i{<unsigned>}
 @result{} @pxref{funct:unur_dstd_set_variant,,@command{unur_dstd_set_variant}}
@end table

@sp 1
@item @code{method = empk} @ @ @ @  @result{} @command{unur_empk_new}
(@pxref{EMPK})
@table @code
@item beta = @i{<double>}
 @result{} @pxref{funct:unur_empk_set_beta,,@command{unur_empk_set_beta}}
@item kernel = @i{<unsigned>}
 @result{} @pxref{funct:unur_empk_set_kernel,,@command{unur_empk_set_kernel}}
@item positive [= @i{<int>}]
 @result{} @pxref{funct:unur_empk_set_positive,,@command{unur_empk_set_positive}}
@item smoothing = @i{<double>}
 @result{} @pxref{funct:unur_empk_set_smoothing,,@command{unur_empk_set_smoothing}}
@item varcor [= @i{<int>}]
 @result{} @pxref{funct:unur_empk_set_varcor,,@command{unur_empk_set_varcor}}
@end table

@sp 1
@item @code{method = hinv} @ @ @ @  @result{} @command{unur_hinv_new}
(@pxref{HINV})
@table @code
@item boundary = @i{<double>}, @i{<double>} | (@i{<list>})
 @result{} @pxref{funct:unur_hinv_set_boundary,,@command{unur_hinv_set_boundary}}
@item cpoints = (@i{<list>}), @i{<int>}
 @result{} @pxref{funct:unur_hinv_set_cpoints,,@command{unur_hinv_set_cpoints}}
@item guidefactor = @i{<double>}
 @result{} @pxref{funct:unur_hinv_set_guidefactor,,@command{unur_hinv_set_guidefactor}}
@item max_intervals [= @i{<int>}]
 @result{} @pxref{funct:unur_hinv_set_max_intervals,,@command{unur_hinv_set_max_intervals}}
@item order [= @i{<int>}]
 @result{} @pxref{funct:unur_hinv_set_order,,@command{unur_hinv_set_order}}
@item u_resolution = @i{<double>}
 @result{} @pxref{funct:unur_hinv_set_u_resolution,,@command{unur_hinv_set_u_resolution}}
@end table

@sp 1
@item @code{method = ninv} @ @ @ @  @result{} @command{unur_ninv_new}
(@pxref{NINV})
@table @code
@item max_iter [= @i{<int>}]
 @result{} @pxref{funct:unur_ninv_set_max_iter,,@command{unur_ninv_set_max_iter}}
@item start = @i{<double>}, @i{<double>} | (@i{<list>})
 @result{} @pxref{funct:unur_ninv_set_start,,@command{unur_ninv_set_start}}
@item table [= @i{<int>}]
 @result{} @pxref{funct:unur_ninv_set_table,,@command{unur_ninv_set_table}}
@item usenewton  
 @result{} @pxref{funct:unur_ninv_set_usenewton,,@command{unur_ninv_set_usenewton}}
@item useregula  
 @result{} @pxref{funct:unur_ninv_set_useregula,,@command{unur_ninv_set_useregula}}
@item x_resolution = @i{<double>}
 @result{} @pxref{funct:unur_ninv_set_x_resolution,,@command{unur_ninv_set_x_resolution}}
@end table

@sp 1
@item @code{method = srou} @ @ @ @  @result{} @command{unur_srou_new}
(@pxref{SROU})
@table @code
@item cdfatmode = @i{<double>}
 @result{} @pxref{funct:unur_srou_set_cdfatmode,,@command{unur_srou_set_cdfatmode}}
@item pdfatmode = @i{<double>}
 @result{} @pxref{funct:unur_srou_set_pdfatmode,,@command{unur_srou_set_pdfatmode}}
@item r = @i{<double>}
 @result{} @pxref{funct:unur_srou_set_r,,@command{unur_srou_set_r}}
@item usemirror [= @i{<int>}]
 @result{} @pxref{funct:unur_srou_set_usemirror,,@command{unur_srou_set_usemirror}}
@item usesqueeze [= @i{<int>}]
 @result{} @pxref{funct:unur_srou_set_usesqueeze,,@command{unur_srou_set_usesqueeze}}
@item verify [= @i{<int>}]
 @result{} @pxref{funct:unur_srou_set_verify,,@command{unur_srou_set_verify}}
@end table

@sp 1
@item @code{method = ssr} @ @ @ @  @result{} @command{unur_ssr_new}
(@pxref{SSR})
@table @code
@item cdfatmode = @i{<double>}
 @result{} @pxref{funct:unur_ssr_set_cdfatmode,,@command{unur_ssr_set_cdfatmode}}
@item pdfatmode = @i{<double>}
 @result{} @pxref{funct:unur_ssr_set_pdfatmode,,@command{unur_ssr_set_pdfatmode}}
@item usesqueeze [= @i{<int>}]
 @result{} @pxref{funct:unur_ssr_set_usesqueeze,,@command{unur_ssr_set_usesqueeze}}
@item verify [= @i{<int>}]
 @result{} @pxref{funct:unur_ssr_set_verify,,@command{unur_ssr_set_verify}}
@end table

@sp 1
@item @code{method = tabl} @ @ @ @  @result{} @command{unur_tabl_new}
(@pxref{TABL})
@table @code
@item areafraction = @i{<double>}
 @result{} @pxref{funct:unur_tabl_set_areafraction,,@command{unur_tabl_set_areafraction}}
@item boundary = @i{<double>}, @i{<double>} | (@i{<list>})
 @result{} @pxref{funct:unur_tabl_set_boundary,,@command{unur_tabl_set_boundary}}
@item guidefactor = @i{<double>}
 @result{} @pxref{funct:unur_tabl_set_guidefactor,,@command{unur_tabl_set_guidefactor}}
@item max_intervals [= @i{<int>}]
 @result{} @pxref{funct:unur_tabl_set_max_intervals,,@command{unur_tabl_set_max_intervals}}
@item max_sqhratio = @i{<double>}
 @result{} @pxref{funct:unur_tabl_set_max_sqhratio,,@command{unur_tabl_set_max_sqhratio}}
@item nstp [= @i{<int>}]
 @result{} @pxref{funct:unur_tabl_set_nstp,,@command{unur_tabl_set_nstp}}
@item slopes = (@i{<list>}), @i{<int>}
 @result{} @pxref{funct:unur_tabl_set_slopes,,@command{unur_tabl_set_slopes}}
@item variant_setup = @i{<unsigned>}
 @result{} @pxref{funct:unur_tabl_set_variant_setup,,@command{unur_tabl_set_variant_setup}}
@item variant_splitmode = @i{<unsigned>}
 @result{} @pxref{funct:unur_tabl_set_variant_splitmode,,@command{unur_tabl_set_variant_splitmode}}
@item verify [= @i{<int>}]
 @result{} @pxref{funct:unur_tabl_set_verify,,@command{unur_tabl_set_verify}}
@end table

@sp 1
@item @code{method = tdr} @ @ @ @  @result{} @command{unur_tdr_new}
(@pxref{TDR})
@table @code
@item c = @i{<double>}
 @result{} @pxref{funct:unur_tdr_set_c,,@command{unur_tdr_set_c}}
@item center = @i{<double>}
 @result{} @pxref{funct:unur_tdr_set_center,,@command{unur_tdr_set_center}}
@item cpoints = @i{<int>} [, (@i{<list>})] | (@i{<list>})
 @result{} @pxref{funct:unur_tdr_set_cpoints,,@command{unur_tdr_set_cpoints}}
@item darsfactor = @i{<double>}
 @result{} @pxref{funct:unur_tdr_set_darsfactor,,@command{unur_tdr_set_darsfactor}}
@item guidefactor = @i{<double>}
 @result{} @pxref{funct:unur_tdr_set_guidefactor,,@command{unur_tdr_set_guidefactor}}
@item max_intervals [= @i{<int>}]
 @result{} @pxref{funct:unur_tdr_set_max_intervals,,@command{unur_tdr_set_max_intervals}}
@item max_sqhratio = @i{<double>}
 @result{} @pxref{funct:unur_tdr_set_max_sqhratio,,@command{unur_tdr_set_max_sqhratio}}
@item pedantic [= @i{<int>}]
 @result{} @pxref{funct:unur_tdr_set_pedantic,,@command{unur_tdr_set_pedantic}}
@item usecenter [= @i{<int>}]
 @result{} @pxref{funct:unur_tdr_set_usecenter,,@command{unur_tdr_set_usecenter}}
@item usedars [= @i{<int>}]
 @result{} @pxref{funct:unur_tdr_set_usedars,,@command{unur_tdr_set_usedars}}
@item usemode [= @i{<int>}]
 @result{} @pxref{funct:unur_tdr_set_usemode,,@command{unur_tdr_set_usemode}}
@item variant_gw  
 @result{} @pxref{funct:unur_tdr_set_variant_gw,,@command{unur_tdr_set_variant_gw}}
@item variant_ia  
 @result{} @pxref{funct:unur_tdr_set_variant_ia,,@command{unur_tdr_set_variant_ia}}
@item variant_ps  
 @result{} @pxref{funct:unur_tdr_set_variant_ps,,@command{unur_tdr_set_variant_ps}}
@item verify [= @i{<int>}]
 @result{} @pxref{funct:unur_tdr_set_verify,,@command{unur_tdr_set_verify}}
@end table

@sp 1
@item @code{method = utdr} @ @ @ @  @result{} @command{unur_utdr_new}
(@pxref{UTDR})
@table @code
@item cpfactor = @i{<double>}
 @result{} @pxref{funct:unur_utdr_set_cpfactor,,@command{unur_utdr_set_cpfactor}}
@item deltafactor = @i{<double>}
 @result{} @pxref{funct:unur_utdr_set_deltafactor,,@command{unur_utdr_set_deltafactor}}
@item pdfatmode = @i{<double>}
 @result{} @pxref{funct:unur_utdr_set_pdfatmode,,@command{unur_utdr_set_pdfatmode}}
@item verify [= @i{<int>}]
 @result{} @pxref{funct:unur_utdr_set_verify,,@command{unur_utdr_set_verify}}
@end table

@sp 1
@item @code{method = vempk} @ @ @ @  @result{} @command{unur_vempk_new}
(@pxref{VEMPK})
@table @code
@item smoothing = @i{<double>}
 @result{} @pxref{funct:unur_vempk_set_smoothing,,@command{unur_vempk_set_smoothing}}
@item varcor [= @i{<int>}]
 @result{} @pxref{funct:unur_vempk_set_varcor,,@command{unur_vempk_set_varcor}}
@end table

@sp 1
@end itemize


=EON
*/
