/*
	file automatically generated by make_test_files.pl
	Wed Nov  6 10:15:48 2002
*/

/*****************************************************************************
 *                                                                           *
 *          UNURAN -- Universal Non-Uniform Random number generator          *
 *                                                                           *
 *****************************************************************************/
    
/**
 ** Tests for NINV
 **/
    
/*---------------------------------------------------------------------------*/
#include "testunuran.h"
/*---------------------------------------------------------------------------*/

/*---------------------------------------------------------------------------*/
/* global variables                                                          */

static FILE *TESTLOG;               /* test log file                         */
static FILE *UNURANLOG;             /* unuran log file                       */

static int test_ok = TRUE;          /* all tests ok (boolean)                */
static int n_tests_failed;          /* number of failed tests                */

/*---------------------------------------------------------------------------*/

void test_new( void );
void test_set( void );
void test_get( void );
void test_chg( void );
void test_init( void );
void test_reinit( void );
void test_sample( void );
void test_validate( void );

void run_verify_generator( FILE *LOG, int line, UNUR_PAR *par );

int unur_ninv_set_verify( UNUR_PAR *par, int );

/*---------------------------------------------------------------------------*/


/* prototypes */

#define COMPARE_SAMPLE_SIZE   (500)
#define VIOLATE_SAMPLE_SIZE   (20)





/*---------------------------------------------------------------------------*/

int main()
{ 
	/* open log file for unuran and set output stream for unuran messages */
	UNURANLOG = fopen( "t_ninv_unuran.log","w" );
	abort_if_NULL( stderr,-1, UNURANLOG );
	unur_set_stream( UNURANLOG );

	/* open log file for testing */
	TESTLOG = fopen( "t_ninv_test.log","w" );
	abort_if_NULL( stderr,-1, TESTLOG );

	/* write header into log file */
  	{
		time_t started;  
		fprintf(TESTLOG,"\nUNURAN - Universal Non-Uniform RANdom number generator\n\n");
		if (time( &started ) != -1)
			fprintf(TESTLOG,"%s",ctime(&started));
		fprintf(TESTLOG,"\n====================================================\n\n");
	}

        /* seed build-in uniform generators */
        unur_urng_MRG31k3p_seed(14631);
	unur_urng_fish_seed(14631);
	unur_urng_mstd_seed(14631);

	/* seed uniform random number generator */
#if UNUR_URNG_TYPE == UNUR_URNG_PRNG
	unur_set_default_urng(prng_new("mt19937(14631)"));
#elif UNUR_URNG_TYPE == UNUR_URNG_RNGSTREAM
	{
	    unsigned long seed[6] = {14631,14631+1,14631+2,14631+3,14631+4,14631+5};
	    RngStream_SetPackageSeed(seed);
	}
#endif  /* UNUR_URNG_TYPE */

	/* set default debugging flag */
	unur_set_default_debug(UNUR_DEBUG_ALL);

	/* start test */
	printf("ninv: ");

	/* run tests */
	test_new();
	test_set();
	test_get();
	test_chg();
	test_init();
	test_sample();
	test_reinit();
	test_validate();

	/* test finished */
	printf("\n");  fflush(stdout);

	/* close log files */
	fprintf(TESTLOG,"\n====================================================\n\n");
	if (test_ok)
		fprintf(TESTLOG,"All tests PASSED.\n");
	else
		fprintf(TESTLOG,"Test(s) FAILED.\n");

	fclose(UNURANLOG);
	fclose(TESTLOG);

	/* free memory */
        compare_free_memory();

	/* exit */
	exit( (test_ok) ? 0 : -1 );

} /* end of main */

/*---------------------------------------------------------------------------*/

void test_new (void)
{
	/* start test */
	printf("[new "); fflush(stdout);
	fprintf(TESTLOG,"\n[new]\n");

	/* reset counter */
	n_tests_failed = 0;
  
/* invalid NULL ptr */
{
UNUR_DISTR *distr = NULL;
   distr = NULL; 

unur_errno = 0;
n_tests_failed += check_expected_NULL( TESTLOG, 27, (unur_ninv_new( distr )) );
n_tests_failed += check_errorcode( TESTLOG, 27, UNUR_ERR_NULL );
unur_distr_free(distr);
}

/* invalid distribution type */
{
UNUR_DISTR *distr = NULL;
   distr = unur_distr_discr_new(); 

unur_errno = 0;
n_tests_failed += check_expected_NULL( TESTLOG, 33, (unur_ninv_new( distr )) );
n_tests_failed += check_errorcode( TESTLOG, 33, UNUR_ERR_DISTR_INVALID );
unur_distr_free(distr);
}

/* data missing in distribution object */
{
UNUR_DISTR *distr = NULL;
   distr = unur_distr_cont_new(); 

unur_errno = 0;
/* cdf */
n_tests_failed += check_expected_NULL( TESTLOG, 40, (unur_ninv_new( distr )) );
n_tests_failed += check_errorcode( TESTLOG, 40, UNUR_ERR_DISTR_REQUIRED );
unur_distr_free(distr);
}


	/* test finished */
	test_ok &= (n_tests_failed) ? 0 : 1;
	(n_tests_failed) ? printf("--> failed] ") : printf("--> ok] ");

#if WITH_DMALLOC
	dmalloc_vmessage("section = new  ================================\n",NULL);
	dmalloc_log_unfreed();
#endif

} /* end of test_new() */

/*---------------------------------------------------------------------------*/

void test_set (void)
{
	/* start test */
	printf("[set "); fflush(stdout);
	fprintf(TESTLOG,"\n[set]\n");

	/* reset counter */
	n_tests_failed = 0;
  
/* invalid NULL ptr */
{
UNUR_PAR   *par = NULL;
   par = NULL; 

unur_errno = 0;
n_tests_failed += check_expected_setfailed( TESTLOG, 50, (unur_ninv_set_usenewton( par )) );
n_tests_failed += check_errorcode( TESTLOG, 50, UNUR_ERR_NULL );

unur_errno = 0;
n_tests_failed += check_expected_setfailed( TESTLOG, 53, (unur_ninv_set_useregula( par )) );
n_tests_failed += check_errorcode( TESTLOG, 53, UNUR_ERR_NULL );

unur_errno = 0;
n_tests_failed += check_expected_setfailed( TESTLOG, 56, (unur_ninv_set_max_iter( par, 40 )) );
n_tests_failed += check_errorcode( TESTLOG, 56, UNUR_ERR_NULL );

unur_errno = 0;
n_tests_failed += check_expected_setfailed( TESTLOG, 59, (unur_ninv_set_x_resolution( par, 0.001 )) );
n_tests_failed += check_errorcode( TESTLOG, 59, UNUR_ERR_NULL );

unur_errno = 0;
n_tests_failed += check_expected_setfailed( TESTLOG, 62, (unur_ninv_set_start( par, 0., 1. )) );
n_tests_failed += check_errorcode( TESTLOG, 62, UNUR_ERR_NULL );

unur_errno = 0;
n_tests_failed += check_expected_setfailed( TESTLOG, 65, (unur_ninv_set_table( par, 100 )) );
n_tests_failed += check_errorcode( TESTLOG, 65, UNUR_ERR_NULL );
}

/* invalid parameter object */
{
UNUR_DISTR *distr = NULL;
UNUR_PAR   *par = NULL;
   double fpar[2] = {0.,1.};
   distr = unur_distr_normal(fpar,2);
   par = unur_arou_new(distr); 

unur_errno = 0;
n_tests_failed += check_expected_setfailed( TESTLOG, 74, (unur_ninv_set_usenewton( par )) );
n_tests_failed += check_errorcode( TESTLOG, 74, UNUR_ERR_PAR_INVALID );

unur_errno = 0;
n_tests_failed += check_expected_setfailed( TESTLOG, 77, (unur_ninv_set_useregula( par )) );
n_tests_failed += check_errorcode( TESTLOG, 77, UNUR_ERR_PAR_INVALID );

unur_errno = 0;
n_tests_failed += check_expected_setfailed( TESTLOG, 80, (unur_ninv_set_max_iter( par, 40 )) );
n_tests_failed += check_errorcode( TESTLOG, 80, UNUR_ERR_PAR_INVALID );

unur_errno = 0;
n_tests_failed += check_expected_setfailed( TESTLOG, 83, (unur_ninv_set_x_resolution( par, 0.001 )) );
n_tests_failed += check_errorcode( TESTLOG, 83, UNUR_ERR_PAR_INVALID );

unur_errno = 0;
n_tests_failed += check_expected_setfailed( TESTLOG, 86, (unur_ninv_set_start( par, 0., 1. )) );
n_tests_failed += check_errorcode( TESTLOG, 86, UNUR_ERR_PAR_INVALID );

unur_errno = 0;
n_tests_failed += check_expected_setfailed( TESTLOG, 89, (unur_ninv_set_table( par, 100 )) );
n_tests_failed += check_errorcode( TESTLOG, 89, UNUR_ERR_PAR_INVALID );
free(par);
unur_distr_free(distr);
}

/* invalid parameters */
{
UNUR_DISTR *distr = NULL;
UNUR_PAR   *par = NULL;
   double fpar[2] = {0.,1.};
   distr = unur_distr_normal(fpar,2);
   par = unur_ninv_new(distr); 

unur_errno = 0;
n_tests_failed += check_expected_setfailed( TESTLOG, 99, (unur_ninv_set_max_iter( par, 0 )) );
n_tests_failed += check_errorcode( TESTLOG, 99, UNUR_ERR_PAR_SET );

unur_errno = 0;
n_tests_failed += check_expected_setfailed( TESTLOG, 102, (unur_ninv_set_x_resolution( par, 1e-30 )) );
n_tests_failed += check_errorcode( TESTLOG, 102, UNUR_ERR_PAR_SET );
free(par);
unur_distr_free(distr);
}


	/* test finished */
	test_ok &= (n_tests_failed) ? 0 : 1;
	(n_tests_failed) ? printf("--> failed] ") : printf("--> ok] ");

#if WITH_DMALLOC
	dmalloc_vmessage("section = set  ================================\n",NULL);
	dmalloc_log_unfreed();
#endif

} /* end of test_set() */

/*---------------------------------------------------------------------------*/

void test_get (void)
{
	/* start test */
	printf("[get "); fflush(stdout);
	fprintf(TESTLOG,"\n[get]\n");

	/* reset counter */
	n_tests_failed = 0;
  

	/* test finished */
	test_ok &= (n_tests_failed) ? 0 : 1;
	(n_tests_failed) ? printf("--> failed] ") : printf("--> ok] ");

#if WITH_DMALLOC
	dmalloc_vmessage("section = get  ================================\n",NULL);
	dmalloc_log_unfreed();
#endif

} /* end of test_get() */

/*---------------------------------------------------------------------------*/

void test_chg (void)
{
	/* start test */
	printf("[chg "); fflush(stdout);
	fprintf(TESTLOG,"\n[chg]\n");

	/* reset counter */
	n_tests_failed = 0;
  
/* invalid generator object */
{
UNUR_DISTR *distr = NULL;
UNUR_PAR   *par = NULL;
UNUR_GEN   *gen = NULL;
   double fpar[2] = {0.,1.};
   distr = unur_distr_normal(fpar,2);
   unur_distr_cont_set_domain(distr,-1.,2.);
   par = unur_ninv_new(distr);
   unur_set_debug(par,0);
   gen = unur_init( par ); 
abort_if_NULL(TESTLOG, 120,    gen );

unur_errno = 0;
n_tests_failed += check_expected_setfailed( TESTLOG, 124, (unur_ninv_chg_max_iter( gen, 0 )) );
n_tests_failed += check_errorcode( TESTLOG, 124, UNUR_ERR_PAR_SET );

unur_errno = 0;
n_tests_failed += check_expected_setfailed( TESTLOG, 127, (unur_ninv_chg_x_resolution( gen, 1.e-30)) );
n_tests_failed += check_errorcode( TESTLOG, 127, UNUR_ERR_PAR_SET );

unur_errno = 0;
n_tests_failed += check_expected_setfailed( TESTLOG, 130, (unur_ninv_chg_truncated( gen, 1., 0. )) );
n_tests_failed += check_errorcode( TESTLOG, 130, UNUR_ERR_DISTR_SET );

unur_errno = 0;
unur_ninv_chg_truncated( gen, -2., 0. );
n_tests_failed += check_errorcode( TESTLOG, 133, UNUR_ERR_DISTR_SET );

unur_errno = 0;
unur_ninv_chg_truncated( gen, 0., 10. );
n_tests_failed += check_errorcode( TESTLOG, 136, UNUR_ERR_DISTR_SET );
unur_free(gen);
unur_distr_free(distr);
}


	/* test finished */
	test_ok &= (n_tests_failed) ? 0 : 1;
	(n_tests_failed) ? printf("--> failed] ") : printf("--> ok] ");

#if WITH_DMALLOC
	dmalloc_vmessage("section = chg  ================================\n",NULL);
	dmalloc_log_unfreed();
#endif

} /* end of test_chg() */

/*---------------------------------------------------------------------------*/

void test_init (void)
{
	/* start test */
	printf("[init "); fflush(stdout);
	fprintf(TESTLOG,"\n[init]\n");

	/* reset counter */
	n_tests_failed = 0;
  
/* invalid NULL ptr */
{
UNUR_PAR   *par = NULL;
   par = NULL; 

unur_errno = 0;
n_tests_failed += check_expected_NULL( TESTLOG, 147, (unur_init( par )) );
n_tests_failed += check_errorcode( TESTLOG, 147, UNUR_ERR_NULL );
}


	/* test finished */
	test_ok &= (n_tests_failed) ? 0 : 1;
	(n_tests_failed) ? printf("--> failed] ") : printf("--> ok] ");

#if WITH_DMALLOC
	dmalloc_vmessage("section = init  ================================\n",NULL);
	dmalloc_log_unfreed();
#endif

} /* end of test_init() */

/*---------------------------------------------------------------------------*/

void test_reinit (void)
{
	/* start test */
	printf("[reinit "); fflush(stdout);
	fprintf(TESTLOG,"\n[reinit]\n");

	/* reset counter */
	n_tests_failed = 0;
  

	/* test finished */
	test_ok &= (n_tests_failed) ? 0 : 1;
	(n_tests_failed) ? printf("--> failed] ") : printf("--> ok] ");

#if WITH_DMALLOC
	dmalloc_vmessage("section = reinit  ================================\n",NULL);
	dmalloc_log_unfreed();
#endif

} /* end of test_reinit() */

/*---------------------------------------------------------------------------*/

void test_sample (void)
{
	/* start test */
	printf("[sample "); fflush(stdout);
	fprintf(TESTLOG,"\n[sample]\n");

	/* reset counter */
	n_tests_failed = 0;
  
/* compare clone */
{
UNUR_DISTR *distr = NULL;
UNUR_PAR   *par = NULL;
UNUR_GEN   *gen = NULL;
   UNUR_GEN *clone;
   distr = unur_distr_normal(NULL,0); 
   par = NULL;
   gen = NULL; 

unur_errno = 0;
/* original generator object */
par = unur_ninv_new(distr);
gen = unur_init(par);
n_tests_failed += compare_double_sequence_gen_start( TESTLOG, 166, gen, COMPARE_SAMPLE_SIZE );

unur_errno = 0;
/* clone */
clone = unur_gen_clone(gen);
unur_free(gen);
gen = clone;
n_tests_failed += compare_double_sequence_gen( TESTLOG, 172, gen, COMPARE_SAMPLE_SIZE );
unur_free(gen);
unur_distr_free(distr);
}


	/* test finished */
	test_ok &= (n_tests_failed) ? 0 : 1;
	(n_tests_failed) ? printf("--> failed] ") : printf("--> ok] ");

#if WITH_DMALLOC
	dmalloc_vmessage("section = sample  ================================\n",NULL);
	dmalloc_log_unfreed();
#endif

} /* end of test_sample() */

/*---------------------------------------------------------------------------*/

void test_validate (void)
{
	UNUR_DISTR *distr[33];
	UNUR_PAR *par;
	UNUR_GEN *gen;
	int n_tests_failed = 0;
	double *darray;
	double fpm[10];

	/* start test */
	printf("[validate "); fflush(stdout);
	fprintf(TESTLOG,"\n[validate]\n");

	/* reset counter */
	n_tests_failed = 0;


/* distributions: 33 */
fpm[0] = 1.;
fpm[1] = 2.;
distr[0] = unur_distr_beta(fpm,2);


fpm[0] = 1.;
fpm[1] = 5.;
distr[1] = unur_distr_beta(fpm,2);


fpm[0] = 1.;
fpm[1] = 100.;
distr[2] = unur_distr_beta(fpm,2);


fpm[0] = 3.;
fpm[1] = 4.;
distr[3] = unur_distr_beta(fpm,2);


fpm[0] = 5.;
fpm[1] = 100.;
distr[4] = unur_distr_beta(fpm,2);


fpm[0] = 500.;
fpm[1] = 300.;
distr[5] = unur_distr_beta(fpm,2);


fpm[0] = 5.;
fpm[1] = 10.;
fpm[2] = -3.;
fpm[3] = 15.;
distr[6] = unur_distr_beta(fpm,4);


fpm[0] = 0.5;
fpm[1] = 3.;
distr[28] = unur_distr_beta(fpm,2);


fpm[0] = 5.;
fpm[1] = 0.3;
distr[29] = unur_distr_beta(fpm,2);


fpm[0] = 0.5;
fpm[1] = 0.4;
distr[30] = unur_distr_beta(fpm,2);


distr[7] = unur_distr_cauchy(NULL,0);


fpm[0] = 1.;
fpm[1] = 20.;
distr[8] = unur_distr_cauchy(fpm,2);


distr[24] = unur_distr_exponential(NULL,0);


fpm[0] = 30.;
fpm[1] = -5.;
distr[25] = unur_distr_exponential(fpm,2);


fpm[0] = 1.;
distr[9] = unur_distr_gamma(fpm,1);


fpm[0] = 2.;
distr[10] = unur_distr_gamma(fpm,1);


fpm[0] = 3.;
distr[11] = unur_distr_gamma(fpm,1);


fpm[0] = 10.;
distr[12] = unur_distr_gamma(fpm,1);


fpm[0] = 1000.;
distr[13] = unur_distr_gamma(fpm,1);


fpm[0] = 5.;
fpm[1] = 1000.;
distr[14] = unur_distr_gamma(fpm,2);


fpm[0] = 5.;
fpm[1] = 1.e-5;
distr[15] = unur_distr_gamma(fpm,2);


fpm[0] = 5.;
fpm[1] = 10.;
fpm[2] = 1000;
distr[16] = unur_distr_gamma(fpm,3);


fpm[0] = 0.5;
distr[31] = unur_distr_gamma(fpm,1);


fpm[0] = 0.2;
distr[32] = unur_distr_gamma(fpm,1);


distr[26] = unur_distr_laplace(NULL,0);


fpm[0] = -10.;
fpm[1] = 100.;
distr[27] = unur_distr_laplace(fpm,2);


distr[17] = unur_distr_normal(NULL,0);


fpm[0] = 1.;
fpm[1] = 1.e-5;
distr[18] = unur_distr_normal(fpm,2);


fpm[0] = 0.;
fpm[1] = 1.e+5;
distr[19] = unur_distr_normal(fpm,2);


distr[20] = unur_distr_uniform(NULL,0);


fpm[0] = 1.;
fpm[1] = 20.;
distr[21] = unur_distr_uniform(fpm,2);


distr[22] = unur_distr_cauchy(NULL,0);
unur_distr_cont_set_domain(distr[22],0.1,1.);
unur_distr_cont_upd_mode(distr[22]);
unur_distr_cont_upd_pdfarea(distr[22]);


fpm[0] = 3.;
fpm[1] = 4.;
distr[23] = unur_distr_beta(fpm,2);
unur_distr_cont_set_domain(distr[23],-2.,5.);


	printf("\n(chi^2) "); fflush(stdout);

/* chi^2 tests: 660 */

	unur_set_default_debug(~UNUR_DEBUG_SAMPLE);
	fprintf( TESTLOG,"\nChi^2 Test:\n");

/* distribution [0] */

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[0]);
unur_ninv_set_usenewton(par);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[0]);
unur_ninv_set_usenewton(par);
unur_ninv_set_start(par, 0.1, 0.9);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[0]);
unur_ninv_set_table(par,11);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[0]);
unur_ninv_set_usenewton(par);
unur_ninv_set_table(par,1000);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[0]);
unur_ninv_set_usenewton(par);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[0]);
unur_ninv_set_usenewton(par);
unur_ninv_set_table(par,11);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[0]);
unur_ninv_set_usenewton(par);
unur_ninv_set_table(par,1000);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[0]);
unur_ninv_set_usenewton(par);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[0]);
unur_ninv_set_usenewton(par);
unur_ninv_set_table(par,11);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[0]);
unur_ninv_set_usenewton(par);
unur_ninv_set_table(par,1000);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[0]);
unur_ninv_set_useregula(par);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[0]);
unur_ninv_set_useregula(par);
unur_ninv_set_start(par, 0.1, 0.9);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[0]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,11);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[0]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,1000);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[0]);
unur_ninv_set_useregula(par);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[0]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,11);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[0]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,1000);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[0]);
unur_ninv_set_useregula(par);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[0]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,11);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[0]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,1000);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

/* distribution [1] */

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[1]);
unur_ninv_set_usenewton(par);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[1]);
unur_ninv_set_usenewton(par);
unur_ninv_set_start(par, 0.1, 0.9);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[1]);
unur_ninv_set_table(par,11);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[1]);
unur_ninv_set_usenewton(par);
unur_ninv_set_table(par,1000);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[1]);
unur_ninv_set_usenewton(par);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[1]);
unur_ninv_set_usenewton(par);
unur_ninv_set_table(par,11);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[1]);
unur_ninv_set_usenewton(par);
unur_ninv_set_table(par,1000);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[1]);
unur_ninv_set_usenewton(par);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[1]);
unur_ninv_set_usenewton(par);
unur_ninv_set_table(par,11);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[1]);
unur_ninv_set_usenewton(par);
unur_ninv_set_table(par,1000);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[1]);
unur_ninv_set_useregula(par);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[1]);
unur_ninv_set_useregula(par);
unur_ninv_set_start(par, 0.1, 0.9);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[1]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,11);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[1]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,1000);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[1]);
unur_ninv_set_useregula(par);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[1]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,11);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[1]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,1000);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[1]);
unur_ninv_set_useregula(par);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[1]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,11);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[1]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,1000);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

/* distribution [2] */

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[2]);
unur_ninv_set_usenewton(par);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[2]);
unur_ninv_set_usenewton(par);
unur_ninv_set_start(par, 0.1, 0.9);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[2]);
unur_ninv_set_table(par,11);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[2]);
unur_ninv_set_usenewton(par);
unur_ninv_set_table(par,1000);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[2]);
unur_ninv_set_usenewton(par);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[2]);
unur_ninv_set_usenewton(par);
unur_ninv_set_table(par,11);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[2]);
unur_ninv_set_usenewton(par);
unur_ninv_set_table(par,1000);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[2]);
unur_ninv_set_usenewton(par);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[2]);
unur_ninv_set_usenewton(par);
unur_ninv_set_table(par,11);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[2]);
unur_ninv_set_usenewton(par);
unur_ninv_set_table(par,1000);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[2]);
unur_ninv_set_useregula(par);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[2]);
unur_ninv_set_useregula(par);
unur_ninv_set_start(par, 0.1, 0.9);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[2]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,11);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[2]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,1000);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[2]);
unur_ninv_set_useregula(par);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[2]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,11);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[2]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,1000);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[2]);
unur_ninv_set_useregula(par);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[2]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,11);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[2]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,1000);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

/* distribution [3] */

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[3]);
unur_ninv_set_usenewton(par);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[3]);
unur_ninv_set_usenewton(par);
unur_ninv_set_start(par, 0.1, 0.9);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[3]);
unur_ninv_set_table(par,11);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[3]);
unur_ninv_set_usenewton(par);
unur_ninv_set_table(par,1000);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[3]);
unur_ninv_set_usenewton(par);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[3]);
unur_ninv_set_usenewton(par);
unur_ninv_set_table(par,11);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[3]);
unur_ninv_set_usenewton(par);
unur_ninv_set_table(par,1000);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[3]);
unur_ninv_set_usenewton(par);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[3]);
unur_ninv_set_usenewton(par);
unur_ninv_set_table(par,11);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[3]);
unur_ninv_set_usenewton(par);
unur_ninv_set_table(par,1000);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[3]);
unur_ninv_set_useregula(par);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[3]);
unur_ninv_set_useregula(par);
unur_ninv_set_start(par, 0.1, 0.9);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[3]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,11);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[3]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,1000);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[3]);
unur_ninv_set_useregula(par);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[3]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,11);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[3]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,1000);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[3]);
unur_ninv_set_useregula(par);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[3]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,11);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[3]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,1000);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

/* distribution [4] */

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[4]);
unur_ninv_set_usenewton(par);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[4]);
unur_ninv_set_usenewton(par);
unur_ninv_set_start(par, 0.1, 0.9);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[4]);
unur_ninv_set_table(par,11);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[4]);
unur_ninv_set_usenewton(par);
unur_ninv_set_table(par,1000);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[4]);
unur_ninv_set_usenewton(par);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[4]);
unur_ninv_set_usenewton(par);
unur_ninv_set_table(par,11);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[4]);
unur_ninv_set_usenewton(par);
unur_ninv_set_table(par,1000);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[4]);
unur_ninv_set_usenewton(par);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[4]);
unur_ninv_set_usenewton(par);
unur_ninv_set_table(par,11);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[4]);
unur_ninv_set_usenewton(par);
unur_ninv_set_table(par,1000);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[4]);
unur_ninv_set_useregula(par);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[4]);
unur_ninv_set_useregula(par);
unur_ninv_set_start(par, 0.1, 0.9);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[4]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,11);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[4]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,1000);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[4]);
unur_ninv_set_useregula(par);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[4]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,11);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[4]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,1000);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[4]);
unur_ninv_set_useregula(par);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[4]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,11);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[4]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,1000);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

/* distribution [5] */

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[5]);
unur_ninv_set_usenewton(par);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[5]);
unur_ninv_set_usenewton(par);
unur_ninv_set_start(par, 0.1, 0.9);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[5]);
unur_ninv_set_table(par,11);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[5]);
unur_ninv_set_usenewton(par);
unur_ninv_set_table(par,1000);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[5]);
unur_ninv_set_usenewton(par);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[5]);
unur_ninv_set_usenewton(par);
unur_ninv_set_table(par,11);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[5]);
unur_ninv_set_usenewton(par);
unur_ninv_set_table(par,1000);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[5]);
unur_ninv_set_usenewton(par);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[5]);
unur_ninv_set_usenewton(par);
unur_ninv_set_table(par,11);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[5]);
unur_ninv_set_usenewton(par);
unur_ninv_set_table(par,1000);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[5]);
unur_ninv_set_useregula(par);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[5]);
unur_ninv_set_useregula(par);
unur_ninv_set_start(par, 0.1, 0.9);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[5]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,11);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[5]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,1000);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[5]);
unur_ninv_set_useregula(par);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[5]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,11);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[5]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,1000);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[5]);
unur_ninv_set_useregula(par);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[5]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,11);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[5]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,1000);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

/* distribution [6] */

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[6]);
unur_ninv_set_usenewton(par);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[6]);
unur_ninv_set_usenewton(par);
unur_ninv_set_start(par, 0.1, 0.9);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[6]);
unur_ninv_set_table(par,11);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[6]);
unur_ninv_set_usenewton(par);
unur_ninv_set_table(par,1000);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[6]);
unur_ninv_set_usenewton(par);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[6]);
unur_ninv_set_usenewton(par);
unur_ninv_set_table(par,11);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[6]);
unur_ninv_set_usenewton(par);
unur_ninv_set_table(par,1000);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[6]);
unur_ninv_set_usenewton(par);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[6]);
unur_ninv_set_usenewton(par);
unur_ninv_set_table(par,11);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[6]);
unur_ninv_set_usenewton(par);
unur_ninv_set_table(par,1000);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[6]);
unur_ninv_set_useregula(par);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[6]);
unur_ninv_set_useregula(par);
unur_ninv_set_start(par, 0.1, 0.9);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[6]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,11);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[6]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,1000);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[6]);
unur_ninv_set_useregula(par);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[6]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,11);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[6]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,1000);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[6]);
unur_ninv_set_useregula(par);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[6]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,11);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[6]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,1000);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

/* distribution [28] */

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[28]);
unur_ninv_set_usenewton(par);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[28]);
unur_ninv_set_usenewton(par);
unur_ninv_set_start(par, 0.1, 0.9);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[28]);
unur_ninv_set_table(par,11);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[28]);
unur_ninv_set_usenewton(par);
unur_ninv_set_table(par,1000);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[28]);
unur_ninv_set_usenewton(par);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[28]);
unur_ninv_set_usenewton(par);
unur_ninv_set_table(par,11);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[28]);
unur_ninv_set_usenewton(par);
unur_ninv_set_table(par,1000);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[28]);
unur_ninv_set_usenewton(par);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[28]);
unur_ninv_set_usenewton(par);
unur_ninv_set_table(par,11);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[28]);
unur_ninv_set_usenewton(par);
unur_ninv_set_table(par,1000);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[28]);
unur_ninv_set_useregula(par);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[28]);
unur_ninv_set_useregula(par);
unur_ninv_set_start(par, 0.1, 0.9);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[28]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,11);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[28]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,1000);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[28]);
unur_ninv_set_useregula(par);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[28]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,11);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[28]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,1000);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[28]);
unur_ninv_set_useregula(par);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[28]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,11);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[28]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,1000);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

/* distribution [29] */

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[29]);
unur_ninv_set_usenewton(par);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[29]);
unur_ninv_set_usenewton(par);
unur_ninv_set_start(par, 0.1, 0.9);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[29]);
unur_ninv_set_table(par,11);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[29]);
unur_ninv_set_usenewton(par);
unur_ninv_set_table(par,1000);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[29]);
unur_ninv_set_usenewton(par);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[29]);
unur_ninv_set_usenewton(par);
unur_ninv_set_table(par,11);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[29]);
unur_ninv_set_usenewton(par);
unur_ninv_set_table(par,1000);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[29]);
unur_ninv_set_usenewton(par);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[29]);
unur_ninv_set_usenewton(par);
unur_ninv_set_table(par,11);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[29]);
unur_ninv_set_usenewton(par);
unur_ninv_set_table(par,1000);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[29]);
unur_ninv_set_useregula(par);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[29]);
unur_ninv_set_useregula(par);
unur_ninv_set_start(par, 0.1, 0.9);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[29]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,11);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[29]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,1000);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[29]);
unur_ninv_set_useregula(par);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[29]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,11);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[29]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,1000);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[29]);
unur_ninv_set_useregula(par);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[29]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,11);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[29]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,1000);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

/* distribution [30] */

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[30]);
unur_ninv_set_usenewton(par);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[30]);
unur_ninv_set_usenewton(par);
unur_ninv_set_start(par, 0.1, 0.9);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[30]);
unur_ninv_set_table(par,11);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[30]);
unur_ninv_set_usenewton(par);
unur_ninv_set_table(par,1000);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[30]);
unur_ninv_set_usenewton(par);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[30]);
unur_ninv_set_usenewton(par);
unur_ninv_set_table(par,11);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[30]);
unur_ninv_set_usenewton(par);
unur_ninv_set_table(par,1000);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[30]);
unur_ninv_set_usenewton(par);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[30]);
unur_ninv_set_usenewton(par);
unur_ninv_set_table(par,11);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[30]);
unur_ninv_set_usenewton(par);
unur_ninv_set_table(par,1000);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[30]);
unur_ninv_set_useregula(par);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[30]);
unur_ninv_set_useregula(par);
unur_ninv_set_start(par, 0.1, 0.9);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[30]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,11);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[30]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,1000);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[30]);
unur_ninv_set_useregula(par);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[30]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,11);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[30]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,1000);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[30]);
unur_ninv_set_useregula(par);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[30]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,11);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[30]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,1000);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

/* distribution [7] */

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[7]);
unur_ninv_set_usenewton(par);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[7]);
unur_ninv_set_usenewton(par);
unur_ninv_set_start(par, 0.1, 0.9);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[7]);
unur_ninv_set_table(par,11);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[7]);
unur_ninv_set_usenewton(par);
unur_ninv_set_table(par,1000);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[7]);
unur_ninv_set_usenewton(par);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[7]);
unur_ninv_set_usenewton(par);
unur_ninv_set_table(par,11);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[7]);
unur_ninv_set_usenewton(par);
unur_ninv_set_table(par,1000);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[7]);
unur_ninv_set_usenewton(par);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[7]);
unur_ninv_set_usenewton(par);
unur_ninv_set_table(par,11);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[7]);
unur_ninv_set_usenewton(par);
unur_ninv_set_table(par,1000);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[7]);
unur_ninv_set_useregula(par);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[7]);
unur_ninv_set_useregula(par);
unur_ninv_set_start(par, 0.1, 0.9);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[7]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,11);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[7]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,1000);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[7]);
unur_ninv_set_useregula(par);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[7]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,11);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[7]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,1000);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[7]);
unur_ninv_set_useregula(par);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[7]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,11);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[7]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,1000);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

/* distribution [8] */

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[8]);
unur_ninv_set_usenewton(par);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[8]);
unur_ninv_set_usenewton(par);
unur_ninv_set_start(par, 0.1, 0.9);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[8]);
unur_ninv_set_table(par,11);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[8]);
unur_ninv_set_usenewton(par);
unur_ninv_set_table(par,1000);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[8]);
unur_ninv_set_usenewton(par);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[8]);
unur_ninv_set_usenewton(par);
unur_ninv_set_table(par,11);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[8]);
unur_ninv_set_usenewton(par);
unur_ninv_set_table(par,1000);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[8]);
unur_ninv_set_usenewton(par);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[8]);
unur_ninv_set_usenewton(par);
unur_ninv_set_table(par,11);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[8]);
unur_ninv_set_usenewton(par);
unur_ninv_set_table(par,1000);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[8]);
unur_ninv_set_useregula(par);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[8]);
unur_ninv_set_useregula(par);
unur_ninv_set_start(par, 0.1, 0.9);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[8]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,11);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[8]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,1000);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[8]);
unur_ninv_set_useregula(par);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[8]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,11);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[8]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,1000);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[8]);
unur_ninv_set_useregula(par);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[8]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,11);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[8]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,1000);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

/* distribution [24] */

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[24]);
unur_ninv_set_usenewton(par);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[24]);
unur_ninv_set_usenewton(par);
unur_ninv_set_start(par, 0.1, 0.9);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[24]);
unur_ninv_set_table(par,11);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[24]);
unur_ninv_set_usenewton(par);
unur_ninv_set_table(par,1000);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[24]);
unur_ninv_set_usenewton(par);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[24]);
unur_ninv_set_usenewton(par);
unur_ninv_set_table(par,11);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[24]);
unur_ninv_set_usenewton(par);
unur_ninv_set_table(par,1000);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[24]);
unur_ninv_set_usenewton(par);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[24]);
unur_ninv_set_usenewton(par);
unur_ninv_set_table(par,11);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[24]);
unur_ninv_set_usenewton(par);
unur_ninv_set_table(par,1000);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[24]);
unur_ninv_set_useregula(par);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[24]);
unur_ninv_set_useregula(par);
unur_ninv_set_start(par, 0.1, 0.9);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[24]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,11);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[24]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,1000);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[24]);
unur_ninv_set_useregula(par);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[24]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,11);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[24]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,1000);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[24]);
unur_ninv_set_useregula(par);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[24]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,11);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[24]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,1000);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

/* distribution [25] */

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[25]);
unur_ninv_set_usenewton(par);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[25]);
unur_ninv_set_usenewton(par);
unur_ninv_set_start(par, 0.1, 0.9);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[25]);
unur_ninv_set_table(par,11);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[25]);
unur_ninv_set_usenewton(par);
unur_ninv_set_table(par,1000);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[25]);
unur_ninv_set_usenewton(par);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[25]);
unur_ninv_set_usenewton(par);
unur_ninv_set_table(par,11);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[25]);
unur_ninv_set_usenewton(par);
unur_ninv_set_table(par,1000);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[25]);
unur_ninv_set_usenewton(par);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[25]);
unur_ninv_set_usenewton(par);
unur_ninv_set_table(par,11);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[25]);
unur_ninv_set_usenewton(par);
unur_ninv_set_table(par,1000);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[25]);
unur_ninv_set_useregula(par);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[25]);
unur_ninv_set_useregula(par);
unur_ninv_set_start(par, 0.1, 0.9);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[25]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,11);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[25]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,1000);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[25]);
unur_ninv_set_useregula(par);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[25]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,11);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[25]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,1000);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[25]);
unur_ninv_set_useregula(par);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[25]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,11);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[25]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,1000);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

/* distribution [9] */

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[9]);
unur_ninv_set_usenewton(par);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[9]);
unur_ninv_set_usenewton(par);
unur_ninv_set_start(par, 0.1, 0.9);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[9]);
unur_ninv_set_table(par,11);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[9]);
unur_ninv_set_usenewton(par);
unur_ninv_set_table(par,1000);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[9]);
unur_ninv_set_usenewton(par);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[9]);
unur_ninv_set_usenewton(par);
unur_ninv_set_table(par,11);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[9]);
unur_ninv_set_usenewton(par);
unur_ninv_set_table(par,1000);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[9]);
unur_ninv_set_usenewton(par);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[9]);
unur_ninv_set_usenewton(par);
unur_ninv_set_table(par,11);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[9]);
unur_ninv_set_usenewton(par);
unur_ninv_set_table(par,1000);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[9]);
unur_ninv_set_useregula(par);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[9]);
unur_ninv_set_useregula(par);
unur_ninv_set_start(par, 0.1, 0.9);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[9]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,11);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[9]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,1000);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[9]);
unur_ninv_set_useregula(par);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[9]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,11);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[9]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,1000);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[9]);
unur_ninv_set_useregula(par);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[9]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,11);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[9]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,1000);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

/* distribution [10] */

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[10]);
unur_ninv_set_usenewton(par);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[10]);
unur_ninv_set_usenewton(par);
unur_ninv_set_start(par, 0.1, 0.9);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[10]);
unur_ninv_set_table(par,11);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[10]);
unur_ninv_set_usenewton(par);
unur_ninv_set_table(par,1000);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[10]);
unur_ninv_set_usenewton(par);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[10]);
unur_ninv_set_usenewton(par);
unur_ninv_set_table(par,11);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[10]);
unur_ninv_set_usenewton(par);
unur_ninv_set_table(par,1000);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[10]);
unur_ninv_set_usenewton(par);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[10]);
unur_ninv_set_usenewton(par);
unur_ninv_set_table(par,11);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[10]);
unur_ninv_set_usenewton(par);
unur_ninv_set_table(par,1000);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[10]);
unur_ninv_set_useregula(par);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[10]);
unur_ninv_set_useregula(par);
unur_ninv_set_start(par, 0.1, 0.9);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[10]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,11);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[10]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,1000);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[10]);
unur_ninv_set_useregula(par);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[10]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,11);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[10]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,1000);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[10]);
unur_ninv_set_useregula(par);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[10]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,11);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[10]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,1000);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

/* distribution [11] */

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[11]);
unur_ninv_set_usenewton(par);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[11]);
unur_ninv_set_usenewton(par);
unur_ninv_set_start(par, 0.1, 0.9);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[11]);
unur_ninv_set_table(par,11);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[11]);
unur_ninv_set_usenewton(par);
unur_ninv_set_table(par,1000);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[11]);
unur_ninv_set_usenewton(par);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[11]);
unur_ninv_set_usenewton(par);
unur_ninv_set_table(par,11);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[11]);
unur_ninv_set_usenewton(par);
unur_ninv_set_table(par,1000);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[11]);
unur_ninv_set_usenewton(par);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[11]);
unur_ninv_set_usenewton(par);
unur_ninv_set_table(par,11);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[11]);
unur_ninv_set_usenewton(par);
unur_ninv_set_table(par,1000);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[11]);
unur_ninv_set_useregula(par);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[11]);
unur_ninv_set_useregula(par);
unur_ninv_set_start(par, 0.1, 0.9);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[11]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,11);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[11]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,1000);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[11]);
unur_ninv_set_useregula(par);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[11]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,11);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[11]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,1000);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[11]);
unur_ninv_set_useregula(par);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[11]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,11);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[11]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,1000);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

/* distribution [12] */

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[12]);
unur_ninv_set_usenewton(par);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	printf("."); fflush(stdout);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[12]);
unur_ninv_set_table(par,11);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[12]);
unur_ninv_set_usenewton(par);
unur_ninv_set_table(par,1000);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[12]);
unur_ninv_set_usenewton(par);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[12]);
unur_ninv_set_usenewton(par);
unur_ninv_set_table(par,11);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[12]);
unur_ninv_set_usenewton(par);
unur_ninv_set_table(par,1000);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[12]);
unur_ninv_set_usenewton(par);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[12]);
unur_ninv_set_usenewton(par);
unur_ninv_set_table(par,11);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[12]);
unur_ninv_set_usenewton(par);
unur_ninv_set_table(par,1000);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[12]);
unur_ninv_set_useregula(par);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[12]);
unur_ninv_set_useregula(par);
unur_ninv_set_start(par, 0.1, 0.9);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[12]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,11);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[12]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,1000);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[12]);
unur_ninv_set_useregula(par);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[12]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,11);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[12]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,1000);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[12]);
unur_ninv_set_useregula(par);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[12]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,11);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[12]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,1000);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

/* distribution [13] */

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[13]);
unur_ninv_set_usenewton(par);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	printf("."); fflush(stdout);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[13]);
unur_ninv_set_table(par,11);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[13]);
unur_ninv_set_usenewton(par);
unur_ninv_set_table(par,1000);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[13]);
unur_ninv_set_usenewton(par);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[13]);
unur_ninv_set_usenewton(par);
unur_ninv_set_table(par,11);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[13]);
unur_ninv_set_usenewton(par);
unur_ninv_set_table(par,1000);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[13]);
unur_ninv_set_usenewton(par);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[13]);
unur_ninv_set_usenewton(par);
unur_ninv_set_table(par,11);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[13]);
unur_ninv_set_usenewton(par);
unur_ninv_set_table(par,1000);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[13]);
unur_ninv_set_useregula(par);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[13]);
unur_ninv_set_useregula(par);
unur_ninv_set_start(par, 0.1, 0.9);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[13]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,11);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[13]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,1000);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[13]);
unur_ninv_set_useregula(par);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[13]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,11);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[13]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,1000);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[13]);
unur_ninv_set_useregula(par);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[13]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,11);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[13]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,1000);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

/* distribution [14] */

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[14]);
unur_ninv_set_usenewton(par);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	printf("."); fflush(stdout);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[14]);
unur_ninv_set_table(par,11);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[14]);
unur_ninv_set_usenewton(par);
unur_ninv_set_table(par,1000);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[14]);
unur_ninv_set_usenewton(par);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[14]);
unur_ninv_set_usenewton(par);
unur_ninv_set_table(par,11);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[14]);
unur_ninv_set_usenewton(par);
unur_ninv_set_table(par,1000);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[14]);
unur_ninv_set_usenewton(par);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[14]);
unur_ninv_set_usenewton(par);
unur_ninv_set_table(par,11);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[14]);
unur_ninv_set_usenewton(par);
unur_ninv_set_table(par,1000);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[14]);
unur_ninv_set_useregula(par);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[14]);
unur_ninv_set_useregula(par);
unur_ninv_set_start(par, 0.1, 0.9);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[14]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,11);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[14]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,1000);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[14]);
unur_ninv_set_useregula(par);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[14]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,11);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[14]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,1000);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[14]);
unur_ninv_set_useregula(par);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[14]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,11);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[14]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,1000);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

/* distribution [15] */

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[15]);
unur_ninv_set_usenewton(par);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[15]);
unur_ninv_set_usenewton(par);
unur_ninv_set_start(par, 0.1, 0.9);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[15]);
unur_ninv_set_table(par,11);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[15]);
unur_ninv_set_usenewton(par);
unur_ninv_set_table(par,1000);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[15]);
unur_ninv_set_usenewton(par);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[15]);
unur_ninv_set_usenewton(par);
unur_ninv_set_table(par,11);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[15]);
unur_ninv_set_usenewton(par);
unur_ninv_set_table(par,1000);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[15]);
unur_ninv_set_usenewton(par);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[15]);
unur_ninv_set_usenewton(par);
unur_ninv_set_table(par,11);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[15]);
unur_ninv_set_usenewton(par);
unur_ninv_set_table(par,1000);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[15]);
unur_ninv_set_useregula(par);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[15]);
unur_ninv_set_useregula(par);
unur_ninv_set_start(par, 0.1, 0.9);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[15]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,11);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[15]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,1000);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[15]);
unur_ninv_set_useregula(par);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[15]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,11);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[15]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,1000);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[15]);
unur_ninv_set_useregula(par);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[15]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,11);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[15]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,1000);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

/* distribution [16] */

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[16]);
unur_ninv_set_usenewton(par);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	printf("."); fflush(stdout);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[16]);
unur_ninv_set_table(par,11);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[16]);
unur_ninv_set_usenewton(par);
unur_ninv_set_table(par,1000);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[16]);
unur_ninv_set_usenewton(par);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[16]);
unur_ninv_set_usenewton(par);
unur_ninv_set_table(par,11);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[16]);
unur_ninv_set_usenewton(par);
unur_ninv_set_table(par,1000);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[16]);
unur_ninv_set_usenewton(par);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[16]);
unur_ninv_set_usenewton(par);
unur_ninv_set_table(par,11);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[16]);
unur_ninv_set_usenewton(par);
unur_ninv_set_table(par,1000);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[16]);
unur_ninv_set_useregula(par);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	printf("."); fflush(stdout);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[16]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,11);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[16]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,1000);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[16]);
unur_ninv_set_useregula(par);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[16]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,11);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[16]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,1000);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[16]);
unur_ninv_set_useregula(par);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[16]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,11);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[16]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,1000);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

/* distribution [31] */

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[31]);
unur_ninv_set_usenewton(par);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	printf("."); fflush(stdout);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[31]);
unur_ninv_set_table(par,11);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[31]);
unur_ninv_set_usenewton(par);
unur_ninv_set_table(par,1000);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[31]);
unur_ninv_set_usenewton(par);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[31]);
unur_ninv_set_usenewton(par);
unur_ninv_set_table(par,11);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[31]);
unur_ninv_set_usenewton(par);
unur_ninv_set_table(par,1000);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[31]);
unur_ninv_set_usenewton(par);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[31]);
unur_ninv_set_usenewton(par);
unur_ninv_set_table(par,11);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[31]);
unur_ninv_set_usenewton(par);
unur_ninv_set_table(par,1000);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[31]);
unur_ninv_set_useregula(par);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[31]);
unur_ninv_set_useregula(par);
unur_ninv_set_start(par, 0.1, 0.9);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[31]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,11);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[31]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,1000);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[31]);
unur_ninv_set_useregula(par);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[31]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,11);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[31]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,1000);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[31]);
unur_ninv_set_useregula(par);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[31]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,11);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[31]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,1000);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

/* distribution [32] */

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[32]);
unur_ninv_set_table(par,11);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[32]);
unur_ninv_set_usenewton(par);
unur_ninv_set_table(par,1000);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[32]);
unur_ninv_set_usenewton(par);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[32]);
unur_ninv_set_usenewton(par);
unur_ninv_set_table(par,11);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[32]);
unur_ninv_set_usenewton(par);
unur_ninv_set_table(par,1000);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[32]);
unur_ninv_set_usenewton(par);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[32]);
unur_ninv_set_usenewton(par);
unur_ninv_set_table(par,11);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[32]);
unur_ninv_set_usenewton(par);
unur_ninv_set_table(par,1000);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[32]);
unur_ninv_set_useregula(par);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[32]);
unur_ninv_set_useregula(par);
unur_ninv_set_start(par, 0.1, 0.9);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[32]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,11);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[32]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,1000);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[32]);
unur_ninv_set_useregula(par);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[32]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,11);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[32]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,1000);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[32]);
unur_ninv_set_useregula(par);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[32]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,11);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[32]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,1000);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

/* distribution [26] */

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[26]);
unur_ninv_set_usenewton(par);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[26]);
unur_ninv_set_usenewton(par);
unur_ninv_set_start(par, 0.1, 0.9);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[26]);
unur_ninv_set_table(par,11);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[26]);
unur_ninv_set_usenewton(par);
unur_ninv_set_table(par,1000);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[26]);
unur_ninv_set_usenewton(par);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[26]);
unur_ninv_set_usenewton(par);
unur_ninv_set_table(par,11);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[26]);
unur_ninv_set_usenewton(par);
unur_ninv_set_table(par,1000);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[26]);
unur_ninv_set_usenewton(par);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[26]);
unur_ninv_set_usenewton(par);
unur_ninv_set_table(par,11);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[26]);
unur_ninv_set_usenewton(par);
unur_ninv_set_table(par,1000);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[26]);
unur_ninv_set_useregula(par);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[26]);
unur_ninv_set_useregula(par);
unur_ninv_set_start(par, 0.1, 0.9);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[26]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,11);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[26]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,1000);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[26]);
unur_ninv_set_useregula(par);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[26]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,11);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[26]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,1000);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[26]);
unur_ninv_set_useregula(par);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[26]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,11);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[26]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,1000);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

/* distribution [27] */

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[27]);
unur_ninv_set_usenewton(par);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[27]);
unur_ninv_set_usenewton(par);
unur_ninv_set_start(par, 0.1, 0.9);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[27]);
unur_ninv_set_table(par,11);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[27]);
unur_ninv_set_usenewton(par);
unur_ninv_set_table(par,1000);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[27]);
unur_ninv_set_usenewton(par);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[27]);
unur_ninv_set_usenewton(par);
unur_ninv_set_table(par,11);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[27]);
unur_ninv_set_usenewton(par);
unur_ninv_set_table(par,1000);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[27]);
unur_ninv_set_usenewton(par);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[27]);
unur_ninv_set_usenewton(par);
unur_ninv_set_table(par,11);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[27]);
unur_ninv_set_usenewton(par);
unur_ninv_set_table(par,1000);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[27]);
unur_ninv_set_useregula(par);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[27]);
unur_ninv_set_useregula(par);
unur_ninv_set_start(par, 0.1, 0.9);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[27]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,11);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[27]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,1000);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[27]);
unur_ninv_set_useregula(par);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[27]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,11);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[27]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,1000);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[27]);
unur_ninv_set_useregula(par);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[27]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,11);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[27]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,1000);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

/* distribution [17] */

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[17]);
unur_ninv_set_usenewton(par);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[17]);
unur_ninv_set_usenewton(par);
unur_ninv_set_start(par, 0.1, 0.9);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[17]);
unur_ninv_set_table(par,11);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[17]);
unur_ninv_set_usenewton(par);
unur_ninv_set_table(par,1000);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[17]);
unur_ninv_set_usenewton(par);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[17]);
unur_ninv_set_usenewton(par);
unur_ninv_set_table(par,11);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[17]);
unur_ninv_set_usenewton(par);
unur_ninv_set_table(par,1000);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[17]);
unur_ninv_set_usenewton(par);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[17]);
unur_ninv_set_usenewton(par);
unur_ninv_set_table(par,11);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[17]);
unur_ninv_set_usenewton(par);
unur_ninv_set_table(par,1000);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[17]);
unur_ninv_set_useregula(par);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[17]);
unur_ninv_set_useregula(par);
unur_ninv_set_start(par, 0.1, 0.9);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[17]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,11);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[17]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,1000);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[17]);
unur_ninv_set_useregula(par);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[17]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,11);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[17]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,1000);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[17]);
unur_ninv_set_useregula(par);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[17]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,11);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[17]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,1000);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

/* distribution [18] */

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[18]);
unur_ninv_set_usenewton(par);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[18]);
unur_ninv_set_usenewton(par);
unur_ninv_set_start(par, 0.1, 0.9);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[18]);
unur_ninv_set_table(par,11);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[18]);
unur_ninv_set_usenewton(par);
unur_ninv_set_table(par,1000);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[18]);
unur_ninv_set_usenewton(par);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[18]);
unur_ninv_set_usenewton(par);
unur_ninv_set_table(par,11);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[18]);
unur_ninv_set_usenewton(par);
unur_ninv_set_table(par,1000);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[18]);
unur_ninv_set_usenewton(par);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[18]);
unur_ninv_set_usenewton(par);
unur_ninv_set_table(par,11);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[18]);
unur_ninv_set_usenewton(par);
unur_ninv_set_table(par,1000);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[18]);
unur_ninv_set_useregula(par);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[18]);
unur_ninv_set_useregula(par);
unur_ninv_set_start(par, 0.1, 0.9);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[18]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,11);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[18]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,1000);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[18]);
unur_ninv_set_useregula(par);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[18]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,11);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[18]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,1000);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[18]);
unur_ninv_set_useregula(par);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[18]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,11);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[18]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,1000);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

/* distribution [19] */

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[19]);
unur_ninv_set_usenewton(par);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[19]);
unur_ninv_set_usenewton(par);
unur_ninv_set_start(par, 0.1, 0.9);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[19]);
unur_ninv_set_table(par,11);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[19]);
unur_ninv_set_usenewton(par);
unur_ninv_set_table(par,1000);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[19]);
unur_ninv_set_usenewton(par);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[19]);
unur_ninv_set_usenewton(par);
unur_ninv_set_table(par,11);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[19]);
unur_ninv_set_usenewton(par);
unur_ninv_set_table(par,1000);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[19]);
unur_ninv_set_usenewton(par);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[19]);
unur_ninv_set_usenewton(par);
unur_ninv_set_table(par,11);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[19]);
unur_ninv_set_usenewton(par);
unur_ninv_set_table(par,1000);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[19]);
unur_ninv_set_useregula(par);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[19]);
unur_ninv_set_useregula(par);
unur_ninv_set_start(par, 0.1, 0.9);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[19]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,11);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[19]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,1000);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[19]);
unur_ninv_set_useregula(par);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[19]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,11);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[19]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,1000);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[19]);
unur_ninv_set_useregula(par);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[19]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,11);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[19]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,1000);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

/* distribution [20] */

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[20]);
unur_ninv_set_usenewton(par);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[20]);
unur_ninv_set_usenewton(par);
unur_ninv_set_start(par, 0.1, 0.9);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[20]);
unur_ninv_set_table(par,11);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[20]);
unur_ninv_set_usenewton(par);
unur_ninv_set_table(par,1000);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[20]);
unur_ninv_set_usenewton(par);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[20]);
unur_ninv_set_usenewton(par);
unur_ninv_set_table(par,11);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[20]);
unur_ninv_set_usenewton(par);
unur_ninv_set_table(par,1000);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[20]);
unur_ninv_set_usenewton(par);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[20]);
unur_ninv_set_usenewton(par);
unur_ninv_set_table(par,11);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[20]);
unur_ninv_set_usenewton(par);
unur_ninv_set_table(par,1000);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[20]);
unur_ninv_set_useregula(par);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[20]);
unur_ninv_set_useregula(par);
unur_ninv_set_start(par, 0.1, 0.9);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[20]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,11);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[20]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,1000);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[20]);
unur_ninv_set_useregula(par);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[20]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,11);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[20]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,1000);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[20]);
unur_ninv_set_useregula(par);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[20]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,11);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[20]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,1000);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

/* distribution [21] */

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[21]);
unur_ninv_set_usenewton(par);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[21]);
unur_ninv_set_usenewton(par);
unur_ninv_set_start(par, 0.1, 0.9);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[21]);
unur_ninv_set_table(par,11);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[21]);
unur_ninv_set_usenewton(par);
unur_ninv_set_table(par,1000);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[21]);
unur_ninv_set_usenewton(par);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[21]);
unur_ninv_set_usenewton(par);
unur_ninv_set_table(par,11);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[21]);
unur_ninv_set_usenewton(par);
unur_ninv_set_table(par,1000);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[21]);
unur_ninv_set_usenewton(par);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[21]);
unur_ninv_set_usenewton(par);
unur_ninv_set_table(par,11);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[21]);
unur_ninv_set_usenewton(par);
unur_ninv_set_table(par,1000);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[21]);
unur_ninv_set_useregula(par);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[21]);
unur_ninv_set_useregula(par);
unur_ninv_set_start(par, 0.1, 0.9);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[21]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,11);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[21]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,1000);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[21]);
unur_ninv_set_useregula(par);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[21]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,11);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[21]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,1000);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[21]);
unur_ninv_set_useregula(par);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[21]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,11);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[21]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,1000);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

/* distribution [22] */

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[22]);
unur_ninv_set_usenewton(par);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[22]);
unur_ninv_set_usenewton(par);
unur_ninv_set_start(par, 0.1, 0.9);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[22]);
unur_ninv_set_table(par,11);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[22]);
unur_ninv_set_usenewton(par);
unur_ninv_set_table(par,1000);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[22]);
unur_ninv_set_usenewton(par);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[22]);
unur_ninv_set_usenewton(par);
unur_ninv_set_table(par,11);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[22]);
unur_ninv_set_usenewton(par);
unur_ninv_set_table(par,1000);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[22]);
unur_ninv_set_usenewton(par);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[22]);
unur_ninv_set_usenewton(par);
unur_ninv_set_table(par,11);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[22]);
unur_ninv_set_usenewton(par);
unur_ninv_set_table(par,1000);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[22]);
unur_ninv_set_useregula(par);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[22]);
unur_ninv_set_useregula(par);
unur_ninv_set_start(par, 0.1, 0.9);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[22]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,11);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[22]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,1000);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[22]);
unur_ninv_set_useregula(par);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[22]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,11);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[22]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,1000);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[22]);
unur_ninv_set_useregula(par);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[22]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,11);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[22]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,1000);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

/* distribution [23] */

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[23]);
unur_ninv_set_usenewton(par);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[23]);
unur_ninv_set_usenewton(par);
unur_ninv_set_start(par, 0.1, 0.9);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[23]);
unur_ninv_set_table(par,11);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[23]);
unur_ninv_set_usenewton(par);
unur_ninv_set_table(par,1000);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[23]);
unur_ninv_set_usenewton(par);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[23]);
unur_ninv_set_usenewton(par);
unur_ninv_set_table(par,11);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[23]);
unur_ninv_set_usenewton(par);
unur_ninv_set_table(par,1000);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[23]);
unur_ninv_set_usenewton(par);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[23]);
unur_ninv_set_usenewton(par);
unur_ninv_set_table(par,11);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[23]);
unur_ninv_set_usenewton(par);
unur_ninv_set_table(par,1000);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[23]);
unur_ninv_set_useregula(par);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[23]);
unur_ninv_set_useregula(par);
unur_ninv_set_start(par, 0.1, 0.9);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[23]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,11);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[23]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,1000);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[23]);
unur_ninv_set_useregula(par);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[23]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,11);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[23]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,1000);
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_truncated(gen,0.5,0.9);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[23]);
unur_ninv_set_useregula(par);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[23]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,11);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_ninv_new(distr[23]);
unur_ninv_set_useregula(par);
unur_ninv_set_table(par,1000);
fpm[0] = 2.;
fpm[1] = 4.;
	gen = unur_init(par);
	if (gen) {
unur_ninv_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);


/* free distributions */
	unur_distr_free(distr[0]);
	unur_distr_free(distr[1]);
	unur_distr_free(distr[2]);
	unur_distr_free(distr[3]);
	unur_distr_free(distr[4]);
	unur_distr_free(distr[5]);
	unur_distr_free(distr[6]);
	unur_distr_free(distr[7]);
	unur_distr_free(distr[8]);
	unur_distr_free(distr[9]);
	unur_distr_free(distr[10]);
	unur_distr_free(distr[11]);
	unur_distr_free(distr[12]);
	unur_distr_free(distr[13]);
	unur_distr_free(distr[14]);
	unur_distr_free(distr[15]);
	unur_distr_free(distr[16]);
	unur_distr_free(distr[17]);
	unur_distr_free(distr[18]);
	unur_distr_free(distr[19]);
	unur_distr_free(distr[20]);
	unur_distr_free(distr[21]);
	unur_distr_free(distr[22]);
	unur_distr_free(distr[23]);
	unur_distr_free(distr[24]);
	unur_distr_free(distr[25]);
	unur_distr_free(distr[26]);
	unur_distr_free(distr[27]);
	unur_distr_free(distr[28]);
	unur_distr_free(distr[29]);
	unur_distr_free(distr[30]);
	unur_distr_free(distr[31]);
	unur_distr_free(distr[32]);
#if WITH_DMALLOC
	dmalloc_vmessage("section = validate  ================================\n","");
	dmalloc_log_unfreed();
#endif


	/* test finished */
	test_ok &= (n_tests_failed>2) ? 0 : 1;   /* we accept 2 failure */
	(n_tests_failed>2) ? printf(" --> failed] ") : printf(" --> ok] ");

	/* prevent compiler from making useless annoying warnings */
	distr[0] = NULL;
	par = NULL;
	gen = NULL;
	darray = NULL;
	fpm[0] = 0.;

} /* end of test_validate */

/*---------------------------------------------------------------------------*/




/*---------------------------------------------------------------------------*/
/* run generator in verifying mode */

void run_verify_generator( FILE *LOG, int line, UNUR_PAR *par )
{
	UNUR_GEN *gen;
	int i;

	/* switch to verifying mode */
	unur_ninv_set_verify(par,1);

	/* initialize generator */
	gen = unur_init( par ); abort_if_NULL(LOG, line, gen);

	/* run generator */
	for (i=0; i<VIOLATE_SAMPLE_SIZE; i++)
		unur_sample_cont(gen);

	/* destroy generator */
	unur_free(gen); 

} /* end of run_verify_generator() */

int unur_ninv_set_verify(UNUR_PAR *par, int verify) {return 0;}
